@@ -7,6 +7,9 @@
  * Copyright 2013      Mats Erik Andersson <gnu@gisladisker.se>
  * Copyright 2017      Robert Krause <ruport@f00l.de>
  * Copyright 2017      Sharad B
+ * Copyright 2020      David Polverari <david.polverari@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,41 +26,33 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  *
- * packit official page at https://github.com/eribertomota/packit
+ * packit official page at https://github.com/resurrecting-open-source-projects/packit
  */
 
 #include "print_arp_hdr.h"
 
-void
-print_arp_hdr(u_int8_t *packet)
+void print_arp_hdr(u_int8_t * packet)
 {
-    char *arp_t, *arp_hw_t;
-    u_int16_t frame_t;
+	char *arp_t, *arp_hw_t;
+	u_int16_t frame_t;
 
-    struct libnet_arp_hdr *ahdr;
+	struct libnet_arp_hdr *ahdr;
 
 #ifdef DEBUG
-    fprintf(stdout, "DEBUG: print_arp_hdr()\n");
+	fprintf(stdout, "DEBUG: print_arp_hdr()\n");
 #endif
-
-    ahdr = (struct libnet_arp_hdr *)(packet + g_hdr_len);
-
-    arp_t = retrieve_arp_type(htons(ahdr->ar_op));
-    arp_hw_t = retrieve_arp_hw_type(htons(ahdr->ar_hrd));
-
-    fprintf(stdout, "ARP header:  Type: %s(%d)\n", arp_t, htons(ahdr->ar_op));
-    frame_t = ntohs(*(u_int16_t *)(packet + g_hdr_len - sizeof(u_int16_t)));
-
-    fprintf(stdout, "%s header:  Type: %s(%d)\n",
-            (frame_t == ETHERTYPE_REVARP) ? "RARP": "ARP",
-            arp_t, htons(ahdr->ar_op));
-    fprintf(stdout, "     Hardware Format: %s  Length: %d\n",
-        arp_hw_t,
-        ahdr->ar_hln);
-
-    fprintf(stdout, "     Protocol Format: %d  Length: %d\n",
-        ahdr->ar_pro,
-        ahdr->ar_pln);
-
-    return;
+	ahdr = (struct libnet_arp_hdr *)(packet + g_hdr_len);
+	arp_t = retrieve_arp_type(htons(ahdr->ar_op));
+	arp_hw_t = retrieve_arp_hw_type(htons(ahdr->ar_hrd));
+	fprintf(stdout, "ARP header:  Type: %s(%d)\n", arp_t,
+		htons(ahdr->ar_op));
+	frame_t =
+	    ntohs(*(u_int16_t *) (packet + g_hdr_len - sizeof(u_int16_t)));
+	fprintf(stdout, "%s header:  Type: %s(%d)\n",
+		(frame_t == ETHERTYPE_REVARP) ? "RARP" : "ARP",
+		arp_t, htons(ahdr->ar_op));
+	fprintf(stdout, "     Hardware Format: %s  Length: %d\n",
+		arp_hw_t, ahdr->ar_hln);
+	fprintf(stdout, "     Protocol Format: %d  Length: %d\n",
+		ahdr->ar_pro, ahdr->ar_pln);
 }
